#!/bin/bash
set -vx 
#to calculate the monthly 90th percentil and 10th percentil, and the number of days above the 
#climatological 90 and 10 percentile from daily grib file from a model
#chloe prodhomme 27/02/2014



varlst="sfcwind"

til=10

comp[10]="lt"
comp[90]="gt"
longname["tasmax"]="maximum daily surface temperature"
longname["tasmin"]="minimum daily surface temperature"
longname["prlr"]="daily total precipitations"
longname["sfcwind"]="module of the wind"

exp=ERAI

mkdir /scratch/$(whoami)
#rm -rf /scratch/$(whoami)/$exp 
mkdir /scratch/$(whoami)/$exp 
mkdir /scratch/$(whoami)/work/
work=/scratch/$(whoami)/work/${exp}
#rm -rf $work
mkdir $work 
y1=1981
y2=2010
freq=_f6h

for var in $varlst 
do
# here you can select the month start dates 
   for monstrt in 01 02 03 04 05 06 07 08 09 10 11 12 
    do
	data=/cfu/data/ecmwf/eraint/daily/${var}/ # directory where the data are saved
        for year in  `seq $y1 $y2` # period of data
	do 
	    var2=$var # new variable
	    dirdaystat=$data 
	    file=${var}_${year}${monstrt}.nc # output netcdf
	    
	    if [[ $var == "sfcwind" ]] # in the loop neccessary because the variable sfcwind is not defined yet
	    then
		#calculate the module of wind from 6hourly data

		data=/cfu/data/ecmwf/eraint/6hourly/${var}/ # directory where the data are saved
		dirdaystat=$data 
		cdo -r mul ${data/sfcwind/uas}/uas_${year}${monstrt}01.nc ${data/sfcwind/uas}/uas_${year}${monstrt}01.nc $work/uas2_${year}${monstrt}.nc # calculate u*u	
		cdo -r mul ${data/sfcwind/vas}/vas_${year}${monstrt}01.nc ${data/sfcwind/vas}/vas_${year}${monstrt}01.nc $work/vas2_${year}${monstrt}.nc # calculate v*v	
  		cdo -r add $work/uas2_${year}${monstrt}.nc $work/vas2_${year}${monstrt}.nc $work/uas2-vas2_${year}${monstrt}.nc	# add u2+v2
		cdo -r sqrt $work/uas2-vas2_${year}${monstrt}.nc $work/sfcwind_${year}${monstrt}.nc # (square root of u2+v2) module of wind speed
		# daily mean of module of wind
		cdo -r daymean $work/sfcwind_${year}${monstrt}.nc $work/daymean_sfcwind_${year}${monstrt}.nc
		dirdaystat=/scratch/$(whoami)/$exp
		cp  $work/daymean_sfcwind_${year}${monstrt}.nc  $dirdaystat/sfcwind_${year}${monstrt}.nc
		
	    else
		cp $data/$file $work/$file
	    fi

 #calculate 10 and 90 percentile

	    cdo -r monmin $work/$file $work/monmin_${file}
	    cdo -r monmax $work/$file $work/monmax_${file}
	    
	    cdo -r monpctl,$til $work/$file $work/monmin_${file} $work/monmax_${file} $work/q${til}_${file}

	    if [[ $var == "sfcwind" ]]
	    then
		ncrename -h -v uas,${var}_q$til $work/q${til}_${file}

	    else
		ncrename -h -v $var,${var}_q$til $work/q${til}_${file}
	    fi

	    ncatted -h -a long_name,${var2}_q$til,m,c,"monthly ${til} percentile of ${longname[$var2]}" $work/q${til}_${file}
	    ncatted -h -O -a history,global,d,, $work/q${til}_$file

	    dataout=/cfu/data/ecmwf/eraint/monthly_statistics/${var}_q${til}
	    mkdir $dataout
	    cp $work/q${til}_${file} $dataout/${var2}_q${til}_${year}${monstrt}.nc
	done #yearlst

	    #calculate the number of day in a month over/under the climatological 10 and 90 percentil 
	
	#merge all daystat for the choosen time period
	file_out=cat_${var2}_${y1}${monstrt}_${y2}${monstrt}.nc
	ls $work/${file_out} ||  cdo -r mergetime $(ls -1 $dirdaystat/${var2}_????${monstrt}.nc | sed -n -e "/${var2}_${y1}${monstrt}.nc/,/${var2}_${y1}${monstrt}.nc/p") $work/$file_out

	    #calculate the climatological percentil
	cdo -r ymonmin $work/$file_out $work/ymonmin_${file_out}
	cdo -r ymonmax $work/$file_out $work/ymonmax_${file_out}
	climtil=ymonq${til}_${file_out}
	cdo -r ymonpctl,$til $work/$file_out $work/ymonmin_${file_out} $work/ymonmax_${file_out} $work/$climtil 
	for year in `seq $y1 $y2`
	do
	    	#transform monthly file in daily file
		#need to be put in the loop for february
	    imon=0
		#to be kept in the loop for 29feb case
	    DATE=${year}${monstrt}01
	    nbday=$(( (($(date -u --date=${DATE}+$((imon+1))month +%s) - $(date -u --date=${DATE}+$((imon))month +%s) ))/(60*60*24)))
	    echo $nbday
	    for iday in `seq 1 $nbday`
	    do
		cp $work/$climtil $work/toto$iday.nc				
	    done
	    climtil_comp=daily_$climtil
	    ncrcat -h -O $work/toto*.nc $work/daily_$climtil
	    rm -rf $work/toto*.nc

#comparison between the daily min/max/sum and the comparison daily climtil just created
	    file=$dirdaystat/${var2}_${year}${monstrt}.nc
	    cdo -r ${comp[til]} $file $work/$climtil_comp $work/${comp[til]}q${til}_${var2}_${year}${monstrt}.nc
	    
			#sum to known the number of days
	    cdo -r monmean  $work/${comp[til]}q${til}_${var2}_${year}${monstrt}.nc $work/nbdaysq${til}_${var2}_${year}${monstrt}.nc
	    
	    
	    file=nbdaysq${til}_${var2}_${year}${monstrt}.nc
	    if [[ $var == "sfcwind" ]]
	    then
		ncrename -h -v uas,${var2}_nbdaysq${til}_${y1}-${y2} $work/$file
	    else
		ncrename -h -v $var,${var2}_nbdaysq${til}_${y1}-${y2} $work/$file
	    fi
	    ncatted -h -a long_name,${var2}_nbdaysq${til}_${y1}-${y2},m,c,"number of day over the climatological ${til} percentile" $work/$file
	    ncatted -h -O -a history,global,d,, $work/$work/$file
	    
	    dataout=/cfu/data/ecmwf/eraint/monthly_statistics/${var2}_nbdaysq${til}_$y1-$y2
	    mkdir $dataout

	    mv $work/${file} $dataout/${var2}_nbdaysq${til}_${y1}-${y2}_${year}${monstrt}.nc
	    
	done #yearlst
	#rm -rf $work/*
    done #monlst
done #varlst

