#!/bin/bash 
#SBATCH -n 1
#SBATCH -t 10:00:00
#SBATCH -J monthly_pctl
#SBATCH -o /cfu/scratch/%u/slurm/monthly_pctl-%j.err
#SBATCH -e /cfu/scratch/%u/slurm/monthly_pctl-%j.err

set -vx 
#to calculate the monthly 90th percentil and 10th percentil
#chloe prodhomme 27/02/2014

#mkdir /scratch/apinto/
exptype="ecearth2.3" # "ENSEMBLES" #ecearth2.3
explst=b0cm #"cmcc" #b0cm
varlst=sfcwind #tasmax #for ENSEMBLES : tasmax/tasmin

til=90
NLT=4
y1=1981
y2=2010
rerunpctl=0

comp[10]="lt"
comp[90]="gt"
longname["tasmax"]="maximum daily surface temperature"
longname["tasmin"]="minimum daily surface temperature"
longname["prlr"]="daily total precipitations"
longname["sfcwind"]="module of the wind"


monlst=(05) #start month
mkdir /scratch/$(whoami)
mkdir /scratch/$(whoami)/monthly_pctl$SLURM_JOBID/

for exp in ${explst[@]}
do
    rm -rf /scratch/$(whoami)/monthly_pctl$SLURM_JOBID/$exp
    mkdir /scratch/$(whoami)/monthly_pctl$SLURM_JOBID/$exp
    work=/scratch/$(whoami)/monthly_pctl$SLURM_JOBID/work/${exp}
    rm -rf $work
    mkdir /scratch/$(whoami)/monthly_pctl$SLURM_JOBID/work/
    mkdir $work
    for var in ${varlst[@]}
    do
        for monstrt in ${monlst[@]}
        do
            dirdaystat=/scratch/$(whoami)/monthly_pctl$SLURM_JOBID/${exp}/${var}_day${daystat}
           #generate the header 
            case $exptype in
                "ecearth2.3") 
                    nmemb=10
                    suff="_6hourly"
                    data=/cfunas/exp/ecearth/${exp}/daily_grb/${var}_6hourly
                    dataout=/cfunas/exp/ecearth/${exp}/monthly_statistics/
                    mkdir $dataout
                    if [[ $var == "sfcwind" ]]
                    then
                        ncks -O -h -x -v  uas,latitude,longitude,level_$var /cfunas/exp/ecearth/${exp}/monthly_mean/uas_6hourly/uas_${y1}${monstrt}01.nc ${work}/header.nc
                    else
                        ncks -O -h -x -v  $var,latitude,longitude,level_$var ${data/daily_grb/monthly_mean}/${var}_${y1}${monstrt}01.nc ${work}/header.nc
                    fi
                    ;;
                "ENSEMBLES")
                    nmemb=9
                    data=/cfunas/exp/ENSEMBLES/seasonal/${exp}/daily/${var}/
                    dataout=/cfunas/exp/ENSEMBLES/seasonal/${exp}/monthly_statistics/
                    mkdir $dataout
                    ncks -x -O -h -v  $var,latitude,longitude $data/${var}_${y1}${monstrt}01.nc ${work}/header-aux.nc 
                    suff=""
                    ncks -O -d time,1,$NLT ${work}/header-aux.nc  ${work}/header.nc
        #if you want to have a proper time and time_bnd value modify : ${work}/header.nc
                    ;;    
            esac
            for year in `seq $y1 $y2`
            do
    #calculate daily stat in the "ecearth2.3" case
                case $exptype in
                    "ecearth2.3")
                        case $var in 
                            "prlr" )
                                varauxlst="lsp cp"
                                var2=prlr
                                freq=24
                                oldname="LSP"
                                daystat=sum
                                ;;
                            "sfcwind" )
                                varauxlst="uas vas"
                                var2=sfcwind
                                freq=6
                                oldname="U10M"
                                daystat=mean  
                                ;;
                            "tas" )
                                if [[ $til == "10" ]]
                                then
                                    daystat=min
                                fi
                                if [[ $til == "90" ]]
                                then
                                    daystat=max
                                fi
                                varauxlst="tas"
                                var2=tas$daystat
                                oldname="T2M"
                                freq=6
                                ;;
                        esac
                        dirdaystat=/scratch/$(whoami)/monthly_pctl$SLURM_JOBID/${exp}/${var2}

                        for varaux in $varauxlst
                        do          
                            data=/cfunas/exp/ecearth/${exp}/daily_grb/${varaux}_6hourly
                            file=${varaux}_${year}${monstrt}01
                            DATE=${year}${monstrt}01
                #number of timestep
                            step=$(( (($(date -u --date=${DATE}+${NLT}month +%s) - $(date -u --date=${DATE} +%s) ))/(60*60*$freq)))
                            cdo setgridtype,regular $data/${file}.grb $work/${file}.grb
                            cdo -r -t ecmwf -f nc copy $work/$file.grb $work/${file}.nc
                            #loop over the members
                            for r in `seq 1 $nmemb`
                            do
                                ncks -O -d time,$(($r-1)),,$nmemb $work/${file}.nc $work/${file}_r${r}.nc 
                                ncks -O -d time,0,$(($step-1)) $work/${file}_r${r}.nc $work/${file}_r${r}.nc2
                                cdo -r settaxis,$year-${monstrt}-01,00:00,6hour $work/${file}_r${r}.nc2 $work/taxis_$file_r${r}.nc2
                                
                                mv $work/taxis_$file_r${r}.nc2 $work/${file}_r${r}.nc

                            done #r
                #concatenate file
                            ncecat -h -O $work/${file}_r*.nc $work/aux_${file}.nc
                            ncpdq -O -h -a time,record $work/aux_${file}.nc $work/aux_${file}.nc
                            mv $work/aux_${file}.nc $work/$file.nc
                            file=${varaux}_${year}${monstrt}01.nc
                            
                        done
                        if [[ $var == "prlr" ]]
                        then
                            cdo -r add $work/lsp_${year}${monstrt}01.nc $work/cp_${year}${monstrt}01.nc $work/prlr_${year}${monstrt}01.nc  
                            file=prlr_${year}${monstrt}01.nc
                            
                        fi
                        if [[ $var == "sfcwind" ]]
                        then
                            cdo -r mul ${work}/uas_${year}${monstrt}01.nc ${work}/uas_${year}${monstrt}01.nc $work/uas2_${year}${monstrt}01.nc  
                            cdo -r mul ${work}/vas_${year}${monstrt}01.nc ${work}/vas_${year}${monstrt}01.nc $work/vas2_${year}${monstrt}01.nc  
                            cdo -r add $work/uas2_${year}${monstrt}01.nc $work/vas2_${year}${monstrt}01.nc $work/uas2-vas2_${year}${monstrt}01.nc  
                            cdo -r sqrt $work/uas2-vas2_${year}${monstrt}01.nc $work/sfcwind_${year}${monstrt}01.nc
                            file=sfcwind_${year}${monstrt}01.nc
                            
                        fi

                                #calculate min, max sum or mean according to the variable
                        cdo -r day${daystat} $work/${file} $work/day${daystat}_${file}
                        mv  $work/day${daystat}_${file} $work/${file}

                        ncrename -O -v $oldname,$var2 $work/$file
                        #copy daily stat for calculate the climatology
                        mkdir /scratch/$(whoami)/monthly_pctl$SLURM_JOBID/${exp}/
                        mkdir $dirdaystat
                        cp $work/$file $dirdaystat/$file
                        
                        ;;

                    

        #in ensemble case just the set the time axis of the daily file
                    "ENSEMBLES")
                        var2=$var
                        dirdaystat=/scratch/$(whoami)/monthly_pctl$SLURM_JOBID/${exp}/${var2}
                        mkdir /scratch/$(whoami)/monthly_pctl$SLURM_JOBID/${exp}/
                        mkdir $dirdaystat
                        file=${var}_${year}${monstrt}01.nc
                        cp $data/$file $work/$file
                        cdo -r settaxis,$year-${monstrt}-01,12:00,1day $work/$file $work/taxis_$file
                        ncks -O -h -x -v realization $work/taxis_$file $work/norea_taxis_$file
                        ncrename -d reftime,time  $work/norea_taxis_$file
                        ncrename -v reftime,time  $work/norea_taxis_$file
                        cp  $work/norea_taxis_$file $dirdaystat/$file
                        file=taxis_$file
                        ;;
                esac
                
 #calculate 10 and 90 percentile
                cdo -r monmin $work/$file $work/monmin_${file}
                cdo -r monmax $work/$file $work/monmax_${file}
                
                cdo -r monpctl,$til $work/$file $work/monmin_${file} $work/monmax_${file} $work/q${til}_${file}

#set header and variables name properly
                file=q${til}_${file}
                
                ncrename -O -h -v ${var2},${var2}_q$til $work/${file} $work/${file}1    
                ncrename -O -h -d lev,ensemble $work/${file}1 $work/${file}2
                cp $work/${file}2 $work/${file}6
                if [[ $exptype == "ecearth2.3" ]]
                then
                    ncrename -O -h -d lon,longitude $work/${file}2 $work/${file}3
                    ncrename -O -h -d lat,latitude $work/${file}3 $work/${file}4
                    ncrename -O -h -v lon,longitude $work/${file}4 $work/${file}5
                    ncrename -O -h -v lat,latitude $work/${file}5 $work/${file}6
                fi
                ncrename -h -v time,leadtime $work/${file}6
                
                

                ncks -A $work/header.nc  $work/${file}6
                ncecat -O -h $work/${file}6 $work/${file}7
                ncpdq -O -h -a time,record $work/${file}7 $work/${file}8
                ncwa -O  -h -a record $work/${file}8 $work/${file}9
                ncks -x -O -h -v lev $work/${file}9 $work/${file}10
                ncatted -h -a long_name,${var2}_q$til,m,c,"monthly ${til} percentile of ${longname[$var2]}" $work/${file}10
                ncatted -h -O -a history,global,d,, $work/${file}10
                mkdir $dataout
                mkdir $dataout/${var2}_q${til}$suff/

                cp $work/${file}10 $dataout/${var2}_q${til}${suff}/${var2}_q${til}_${year}${monstrt}01.nc
                chmod 770  $dataout/${var2}_q${til}$suff/${var2}_q${til}_${year}${monstrt}01.nc
            done #yearlst
        done #monlst
    done #varlst
done #explst
rm -rf /scratch/$(whoami)/monthly_pctl$SLURM_JOBID